/// <reference types="mathjax2" />

import MarkdownIt from 'markdown-it';
import { MathJaxConfig as MathJaxConfig_2 } from 'mathjax-full/js/components/startup';
import { MathJaxObject as MathJaxObject_2 } from 'mathjax-full/js/components/startup';
import type MdAnchor from 'markdown-it-anchor';
import { Options } from 'linkify-it';
import type { PluginWithOptions } from 'markdown-it';
import { RuleBlock } from 'markdown-it/lib/parser_block';

export declare const anchorOption: MdAnchor.AnchorOptions;

export declare const createMathJaxRenderer: <T extends Partial<MathJax2RendererConfig | MathJax3RendererConfig>>(rendererConfig: T) => IMathRenderer<MathEngine.MathJax2> | IMathRenderer<MathEngine.MathJax3>;

export declare const defaultLinkifyOptions: LinkifyOption;

export declare const defaultMarkdownItOption: MarkdownItPresetOption;

export declare const defaultTaskListsOption: TaskListsOption;

export declare interface HighlightCodeLinesOptions {
    enable?: (md: MarkdownIt) => boolean;
}

export declare const HighlightCodeLinesPlugin: PluginWithOptions<HighlightCodeLinesOptions>;

export declare interface IMathRenderer<TEngine extends MathEngine> {
    config(value: Partial<RendererConfig<TEngine>>): this;
    render(container: HTMLElement, callback?: () => unknown): Promise<void>;
}

declare type LinkifyOption = Options & {
    fuzzyLinkUseHttps?: boolean;
};

export { MarkdownIt }

export declare const markdownItFactory: ({ html, codeHighlight, taskListsOption, math, disableRules, linkify: linkifyOption, preserveLineBreaks, enableMarkdownAttrs, }?: MarkdownItPresetOption) => MarkdownIt;

export declare interface MarkdownItPresetOption {
    codeHighlight: boolean;
    math: boolean;
    html: boolean;
    disableRules: string[];
    taskListsOption?: TaskListsOption;
    linkify?: LinkifyOption;
    preserveLineBreaks?: boolean;
    enableMarkdownAttrs?: boolean;
}

export declare enum MathEngine {
    MathJax2 = 0,
    MathJax3 = 1
}

export declare type MathJax2RendererConfig = RendererConfig<MathEngine.MathJax2> & {
    engine: MathEngine.MathJax2;
};

export declare type MathJax3RendererConfig = RendererConfig<MathEngine.MathJax3> & {
    engine: MathEngine.MathJax3;
};

declare type MathJaxConfig = MathJaxConfig_2 & {
    tex: Record<string, unknown>;
    [name: string]: unknown;
};

declare interface MathJaxObject {
    config: MathJaxConfig;
    startup: MathJaxObject_2['startup'];
    typeset(arg: unknown[]): void;
    typesetPromise(arg: unknown[]): Promise<void>;
}

export declare interface MultilineBlockquoteOptions {
    enable?: (md: MarkdownIt) => boolean;
}

export declare const MultilineBlockquotePlugin: PluginWithOptions<MultilineBlockquoteOptions>;

export declare const MultilineBlockquoteRule: RuleBlock;

export declare interface RendererConfig<TEngine extends MathEngine> {
    engine: MathEngine;
    entryScript: string;
    document: Document;
    isEnabled: boolean;
    onRendered?: (mathjax: TEngine extends MathEngine.MathJax2 ? typeof MathJax : MathJaxObject) => void | Promise<void>;
    tapMathJaxConfig?: <TConfig = TEngine extends MathEngine.MathJax2 ? MathJax.Config : MathJaxConfig>(config: TConfig) => TConfig;
}

export declare interface TaskListsOption {
    enable: boolean;
    label: boolean;
    labelAfter: boolean;
}

export { }
